# Nldi Xstool

[![PyPI](https://img.shields.io/pypi/v/nldi-xstool.svg)](https://pypi.org/project/nldi-xstool/)
[![Status](https://img.shields.io/pypi/status/nldi-xstool.svg)](https://pypi.org/project/nldi-xstool/)
[![Python Version](https://img.shields.io/pypi/pyversions/nldi-xstool)](https://pypi.org/project/nldi-xstool)
[![License](https://img.shields.io/pypi/l/nldi-xstool)](https://creativecommons.org/publicdomain/zero/1.0/legalcode)

[![Read the documentation at https://nldi-xstool.readthedocs.io/](https://img.shields.io/readthedocs/nldi-xstool/latest.svg?label=Read%20the%20Docs)](https://nldi-xstool.readthedocs.io/)

[![pipeline status](https://code.usgs.gov/wma/nhgf/toolsteam/nldi-xstool/badges/main/pipeline.svg)](https://code.usgs.gov/wma/nhgf/toolsteam/nldi-xstool/-/commits/main)
[![coverage report](https://code.usgs.gov/wma/nhgf/toolsteam/nldi-xstool/badges/main/coverage.svg)](https://code.usgs.gov/wma/nhgf/toolsteam/nldi-xstool/-/commits/main)

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Poetry](https://img.shields.io/badge/poetry-enabled-blue)](https://python-poetry.org/)
[![Conda](https://img.shields.io/badge/conda-enabled-green)](https://anaconda.org/)

## Features

- TODO

## Requirements

- TODO

## Installation

You can install nldi-xstool via
[pip](https://pip.pypa.io/) from [PyPI](https://pypi.org/):

```python
pip install nldi-xstool
```

## Command Line Usage

Please see the {doc}`usage`

## Contributing

Contributions are very welcome.
To learn more, see the {doc}`contributing`.

## License

Distributed under the terms of the [CC0 1.0 Universal license](https://creativecommons.org/publicdomain/zero/1.0/legalcode),
_Nldi Xstool_ is free and open source software.

## Disclaimer

{doc}`disclaimer`

## Issues

If you encounter any problems,
please [file an issue](https://code.usgs.gov/wma/nhgf/toolsteam/nldi-xstool/-/issues) along with a detailed description.

## Credits

This project was generated from
[@hillc-usgs](https://github.com/hillc-usgs)'s [Pygeoapi Plugin
Cookiecutter](https://code.usgs.gov/wma/nhgf/pygeoapi-plugin-cookiecutter)
template.
